@@ -30,12 +30,12 @@
 #include "konversation_log.h"
 #include "konversation_state.h"
 
-#include <kwindowsystem_version.h>
-#if KWINDOWSYSTEM_VERSION < QT_VERSION_CHECK(5, 91, 0)
-#include "config-konversation.h"
-#endif
-
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <KIO/OpenUrlJob>
 #include <KConfig>
 #include <KShell>
@@ -54,9 +54,6 @@
 #include <QTextCursor>
 #include <QDesktopServices>
 #include <QCommandLineParser>
-#if HAVE_X11
-#include <QX11Info>
-#endif
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 #include <QNetworkInformation>
 #endif
@@ -1254,7 +1251,11 @@ void Application::openUrl(const QString& url)
 #else
         auto *job = new KIO::OpenUrlJob(QUrl(url));
         job->setFollowRedirections(false);
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, Application::instance()->getMainWindow()));
+#else
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, Application::instance()->getMainWindow()));
+#endif
         job->start();
 #endif
         return;
@@ -1391,22 +1392,7 @@ void Application::handleOpen(const QList<QUrl>& urls)
 void Application::activateForStartLikeCall()
 {
     mainWindow->show();
-#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 91, 0)
     KWindowSystem::updateStartupId(mainWindow->windowHandle());
-#else
-#if HAVE_X11
-    if (KWindowSystem::isPlatformX11()) {
-        KStartupInfo::setNewStartupId(mainWindow->windowHandle(), QX11Info::nextStartupId());
-    } else
-#endif
-    if (KWindowSystem::isPlatformWayland()) {
-        const QString token = qEnvironmentVariable("XDG_ACTIVATION_TOKEN");
-        if (!token.isEmpty()) {
-            KWindowSystem::setCurrentXdgActivationToken(token);
-            qunsetenv("XDG_ACTIVATION_TOKEN");
-        }
-    }
-#endif
     mainWindow->activateAndRaiseWindow();
 }
 
