@@ -24,6 +24,7 @@
 #include <QTcpSocket>
 #include <QTcpServer>
 
+#include <kwidgetsaddons_version.h>
 #include <KMessageBox>
 #include <KGuiItem>
 
@@ -36,6 +37,7 @@ namespace Konversation
         Chat::Chat(QObject *parent)
             : QObject(parent),
               m_selfOpened(true),
+              m_codec(QTextCodec::codecForLocale()),
               m_dccSocket(nullptr),
               m_dccServer(nullptr),
               m_chatStatus(Configuring),
@@ -62,8 +64,6 @@ namespace Konversation
 
             Q_EMIT aboutToClose();
 
-            m_textStream.setDevice(nullptr);
-
             if (m_dccServer)
             {
                 disconnect(m_dccServer, nullptr, nullptr, nullptr);
@@ -144,14 +144,22 @@ namespace Konversation
             {
                 if (!Preferences::self()->dccChatAutoAccept())
                 {
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                    int ret = KMessageBox::questionTwoActions(nullptr,
+#else
                     int ret = KMessageBox::questionYesNo(nullptr,
+#endif
                                                          i18nc("%1=partnerNick, %2=Servername, %3=dcc extension as chat or wboard", "%1 (on %2) offers to DCC %3 with you", m_partnerNick, server->getServerName(), localizedExtensionString()),
                                                          i18nc("%1=dcc extension as Chat or Whiteboard, %2=partnerNick", "DCC %1 offer from %2", localizedExtensionString(), m_partnerNick),
-                                                         KGuiItem(i18n("Accept")),
-                                                         KGuiItem(i18n("Reject"))
+                                                         KGuiItem(i18n("Accept"), QStringLiteral("dialog-ok")),
+                                                         KGuiItem(i18n("Reject"), QStringLiteral("dialog-cancel"))
                                                          );
 
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
+                    if (ret == KMessageBox::SecondaryAction)
+#else
                     if (ret == KMessageBox::No)
+#endif
                     {
                         setStatus(Aborted, i18nc("%1=dcc extension like Chat or Whiteboard",
                                                  "You rejected the DCC %1 offer.",
@@ -250,13 +258,15 @@ namespace Konversation
 
         bool Chat::setEncoding(const QString &encoding)
         {
+            // TODO: m_encoding is empty by default, so this condition will never be true.
+            // Logic like this since code was added, needs investigation by someone (tm)
             if (m_encoding != encoding && !m_encoding.isEmpty())
             {
                 m_encoding = encoding;
                 QTextCodec *codec = QTextCodec::codecForName(m_encoding.toLatin1());
                 if (codec)
                 {
-                    m_textStream.setCodec(codec);
+                    m_codec = codec;
                     return true;
                 }
             }
@@ -476,7 +486,6 @@ namespace Konversation
 
         void Chat::connectionEstablished()
         {
-            m_textStream.setDevice(m_dccSocket);
             setStatus(Chat::Chatting, i18nc("%1=extension like Chat or Whiteboard, %2 = partnerNick",
                                             "Established DCC %1 connection to %2.",
                                             localizedExtensionString(), m_partnerNick));
@@ -493,7 +502,6 @@ namespace Konversation
         {
             char *buffer = nullptr;
             QString line;
-            QTextCodec *codec = m_textStream.codec();
             qint64 available = m_dccSocket->bytesAvailable();
             if (available < 0)
             {
@@ -506,7 +514,7 @@ namespace Konversation
                 buffer = new char[available + 1];
                 qint64 actual = m_dccSocket->readLine(buffer, available);
                 buffer[actual] = 0;
-                line = codec->toUnicode(buffer);
+                line = m_codec->toUnicode(buffer);
                 delete[] buffer;
 
                 const QStringList &lines = line.split(QLatin1Char('\n'), Qt::SkipEmptyParts);
@@ -528,9 +536,9 @@ namespace Konversation
 
         void Chat::sendRawLine(const QString &text)
         {
-            if (m_dccSocket && m_textStream.device())
+            if (m_dccSocket)
             {
-                m_textStream << text << Qt::endl;
+                m_dccSocket->write(m_codec->fromUnicode(text + QLatin1Char('\n')));
             }
         }
 
@@ -568,7 +576,6 @@ namespace Konversation
                 }
             }
 
-            m_textStream.setDevice(m_dccSocket);
             setStatus(Chat::Chatting, i18nc("%1=dcc extension as Chat or Whiteboard, %2=partnerNick",
                                             "Established DCC %1 connection to %2.",
                                             localizedExtensionString(), m_partnerNick));
