@@ -1,30 +1,19 @@
 /*
-  This class represents a DCC transferlist model.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
-
-/*
-  Copyright (C) 2009,2010 Bernd Buschinski <b.buschinski@web.de>
+    SPDX-FileCopyrightText: 2009, 2010 Bernd Buschinski <b.buschinski@web.de>
 */
 
 #ifndef TRANSFERLISTMODEL_H
 #define TRANSFERLISTMODEL_H
 
+#include <KIO/Global>
+
 #include <QString>
 #include <QTreeWidget>
 #include <QStyledItemDelegate>
-#include <QItemDelegate>
 #include <QSortFilterProxyModel>
 
-#include <kio/global.h>
-
-
 #include "transfer.h"
 
 class KCategoryDrawer;
@@ -78,8 +67,10 @@ namespace Konversation
 
         class TransferSizeDelegate : public QStyledItemDelegate
         {
+            Q_OBJECT
+
         public:
-            explicit TransferSizeDelegate(KCategoryDrawer* categoryDrawer, QObject *parent = 0);
+            explicit TransferSizeDelegate(KCategoryDrawer* categoryDrawer, QObject *parent = nullptr);
 
             QSize sizeHint(const QStyleOptionViewItem & option, const QModelIndex & index) const override;
             void paint(QPainter *painter, const QStyleOptionViewItem & option,
@@ -90,8 +81,10 @@ namespace Konversation
 
         class TransferProgressBarDelegate : public QStyledItemDelegate
         {
+            Q_OBJECT
+
         public:
-            explicit TransferProgressBarDelegate(QObject *parent = 0);
+            explicit TransferProgressBarDelegate(QObject *parent = nullptr);
 
             void paint(QPainter *painter, const QStyleOptionViewItem & option,
                                 const QModelIndex &index) const override;
@@ -100,13 +93,18 @@ namespace Konversation
 
         class TransferListProxyModel : public QSortFilterProxyModel
         {
+            Q_OBJECT
+
         public:
-            explicit TransferListProxyModel(QObject *parent = 0);
+            explicit TransferListProxyModel(QObject *parent = nullptr);
 
             bool lessThan(const QModelIndex &left, const QModelIndex &right) const override;
         };
 
 
+        /**
+         * This class represents a DCC transferlist model.
+         */
         class TransferListModel : public QAbstractListModel
         {
             Q_OBJECT
@@ -164,10 +162,10 @@ namespace Konversation
             inline QString getPositionPrettyText(KIO::fileoffset_t position,
                                                  KIO::filesize_t filesize) const;
             inline QString getSenderAddressPrettyText(Transfer *transfer) const;
-            inline QPixmap getStatusIcon(Transfer::Status status) const;
-            inline QPixmap getTypeIcon(Transfer::Type type) const;
+            inline QIcon getStatusIcon(Transfer::Status status) const;
             inline QString getStatusDescription(Transfer::Status status, Transfer::Type type, const QString& errorMessage = QString()) const;
 
+        private:
             QList<TransferItemData> m_transferList;
             QList<TransferHeaderData> m_headerList;
         };
