@@ -33,8 +33,8 @@ namespace Konversation
         : QDialog(parent)
     {
         setWindowTitle( i18n("Identities") );
-        QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
-        QVBoxLayout *mainLayout = new QVBoxLayout;
+        auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+        auto *mainLayout = new QVBoxLayout;
         setLayout(mainLayout);
         QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
         okButton->setDefault(true);
@@ -44,7 +44,7 @@ namespace Konversation
         okButton->setDefault(true);
 
         // Initialize the dialog widget
-        QWidget* w = new QWidget(this);
+        auto* w = new QWidget(this);
         setupUi(w);
         mainLayout->addWidget(w);
         mainLayout->addWidget(buttonBox);
@@ -246,7 +246,7 @@ namespace Konversation
         refreshCurrentIdentity();
         Preferences::setIdentityList(m_identityList);
         Application::instance()->saveOptions(true);
-        emit identitiesChanged();
+        Q_EMIT identitiesChanged();
         QDialog::accept();
     }
 
