@@ -13,7 +13,6 @@
 #include "application.h"
 
 #include <QHeaderView>
-
 #include <QFileDialog>
 #include <QMenu>
 #include <KToolBar>
@@ -100,8 +99,13 @@ bool ChannelListProxyModel::filterAcceptsRow(int sourceRow, const QModelIndex &s
     QModelIndex index1 = sourceModel()->index(sourceRow, 1, sourceParent);
     QModelIndex index2 = sourceModel()->index(sourceRow, 2, sourceParent);
 
-    return (((m_filterChannel && sourceModel()->data(index0).toString().contains(filterRegExp()))
-        || (m_filterTopic && sourceModel()->data(index2).toString().contains(filterRegExp()))
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    const QRegExp filter = filterRegExp();
+#else
+    const QRegularExpression filter = filterRegularExpression();
+#endif
+    return (((m_filterChannel && sourceModel()->data(index0).toString().contains(filter))
+        || (m_filterTopic && sourceModel()->data(index2).toString().contains(filter))
         || (!m_filterChannel && !m_filterTopic))
         && usersInRange(sourceModel()->data(index1).toInt()));
 }
@@ -184,7 +188,7 @@ ChannelListPanel::ChannelListPanel(QWidget* parent) : ChatWindow(parent)
     connect(m_minUser, QOverload<int>::of(&QSpinBox::valueChanged), this, &ChannelListPanel::filterChanged);
     connect(m_maxUser, QOverload<int>::of(&QSpinBox::valueChanged), this, &ChannelListPanel::filterChanged);
 
-    connect(m_filterLine, &KLineEdit::returnPressed, this, &ChannelListPanel::applyFilterClicked);
+    connect(m_filterLine, &KLineEdit::returnKeyPressed, this, &ChannelListPanel::applyFilterClicked);
     connect(m_filterLine, &KLineEdit::textChanged, this, &ChannelListPanel::filterChanged);
 
     connect(m_filterTimer, &QTimer::timeout, this, &ChannelListPanel::updateFilter);
@@ -215,7 +219,7 @@ void ChannelListPanel::refreshList()
     m_refreshList->setEnabled(false);
     m_tempTimer->start(3000);
 
-    emit refreshChannelList();
+    Q_EMIT refreshChannelList();
 }
 
 void ChannelListPanel::addToChannelList(const QString& channel,int users,const QString& topic)
@@ -273,11 +277,19 @@ void ChannelListPanel::updateFilter()
 
     bool change = false;
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     if (m_proxyModel->filterRegExp().pattern() != text || regexChanged)
+#else
+    if (m_proxyModel->filterRegularExpression().pattern() != text || regexChanged)
+#endif
     {
         change = true;
         if(m_regexState)
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             m_proxyModel->setFilterRegExp(text);
+#else
+            m_proxyModel->setFilterRegularExpression(text);
+#endif
         else
             m_proxyModel->setFilterWildcard(text);
     }
@@ -420,7 +432,7 @@ void ChannelListPanel::joinChannelClicked()
     {
         if(item.column() != 0)
             item = item.sibling(item.row(),0);
-        emit joinChannel(item.data().toString());
+        Q_EMIT joinChannel(item.data().toString());
     }
 }
 
@@ -443,10 +455,10 @@ void ChannelListPanel::contextMenu(const QPoint& p)
         item = item.sibling(item.row(),2);
 
     QString filteredLine = item.data().toString();
-    QMenu* menu = new QMenu(this);
+    auto* menu = new QMenu(this);
 
     // Join Channel Action
-    QAction *joinAction = new QAction(menu);
+    auto *joinAction = new QAction(menu);
     joinAction->setText(i18n("Join Channel"));
     joinAction->setIcon(QIcon::fromTheme(QStringLiteral("irc-join-channel")));
     menu->addAction(joinAction);
@@ -456,14 +468,14 @@ void ChannelListPanel::contextMenu(const QPoint& p)
     menu->addSeparator();
 
     // open URL submenu
-    QMenu* showURLmenu = new QMenu(i18n("Open URL"), menu);
+    auto* showURLmenu = new QMenu(i18n("Open URL"), menu);
 
     const QList<QPair<int, int>> urlRanges = Konversation::getUrlRanges(filteredLine);
 
     for (QPair<int, int> urlRange : urlRanges) {
         QString url = filteredLine.mid(urlRange.first, urlRange.second);
 
-        QAction* action = new QAction(showURLmenu);
+        auto* action = new QAction(showURLmenu);
         action->setText(url);
         action->setData(url);
 
@@ -483,7 +495,7 @@ void ChannelListPanel::contextMenu(const QPoint& p)
 
 void ChannelListPanel::openURL()
 {
-    const QAction* action = qobject_cast<const QAction*>(sender());
+    const auto* action = qobject_cast<const QAction*>(sender());
 
     if (action)
     {
@@ -517,7 +529,7 @@ void ChannelListPanel::emitUpdateInfo()
 {
     QString info;
     info = i18n("Channel List for %1", m_server->getDisplayName());
-    emit updateInfo(info);
+    Q_EMIT updateInfo(info);
 }
 
 void ChannelListPanel::setFilter(const QString& filter)
