@@ -1,12 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2003 Mickael Marchand <marchand@kde.org>
+    SPDX-FileCopyrightText: 2003 Mickael Marchand <marchand@kde.org>
 */
 
 #ifndef KONSOLE_PANEL_H
@@ -31,7 +26,7 @@ class KonsolePanel : public ChatWindow
 
         void setName(const QString& newName) override { ChatWindow::setName(newName); }
 
-        QWidget* getWidget();
+        QWidget* getWidget() const;
 
     Q_SIGNALS:
         void closeView(ChatWindow* view);
@@ -43,7 +38,7 @@ class KonsolePanel : public ChatWindow
         /** Called from ChatWindow adjustFocus */
         void childAdjustFocus() override;
 
-    protected Q_SLOTS:
+    private Q_SLOTS:
         void konsoleChanged(const QString& data);
 
     private:
@@ -51,5 +46,8 @@ class KonsolePanel : public ChatWindow
         QToolButton* m_profileButton;
         QLabel* m_konsoleLabel;
         KParts::ReadOnlyPart *k_part;
+
+        Q_DISABLE_COPY(KonsolePanel)
 };
+
 #endif                                            /* KONSOLE_PANEL_H */
