@@ -19,7 +19,12 @@
 #include <QFileDialog>
 #include <KIO/CopyJob>
 #include <KIO/ApplicationLauncherJob>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <QMenu>
 #include <KMessageBox>
 #include <KStandardAction>
@@ -750,7 +755,11 @@ void IrcContextMenus::processLinkAction(int  actionId, const QString& link)
         {
             // ApplicationLauncherJob ctor without args will invoke the open-with dialog
             auto *job = new KIO::ApplicationLauncherJob();
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+            job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, Application::instance()->getMainWindow()));
+#else
             job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, Application::instance()->getMainWindow()));
+#endif
             job->setUrls({ QUrl(link) });
             job->start();
 
