@@ -38,7 +38,12 @@
 
 #include <KMessageBox>
 #include <KIO/OpenUrlJob>
+#include <kio_version.h>
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+#include <KIO/JobUiDelegateFactory>
+#else
 #include <KIO/JobUiDelegate>
+#endif
 #include <QUrl>
 #include <KXMLGUIFactory>
 #include <KActionCollection>
@@ -2374,7 +2379,7 @@ void ViewContainer::findText()
 {
     if (!m_searchView)
     {
-        KMessageBox::sorry(m_window,
+        KMessageBox::error(m_window,
             i18n("You can only search in text fields."),
             i18n("Find Text Information"));
     }
@@ -2589,7 +2594,11 @@ void ViewContainer::openLogFile(const QString& caption, const QString& file)
     if(Preferences::self()->useExternalLogViewer())
     {
         auto *job = new KIO::OpenUrlJob(QUrl::fromLocalFile(file), QStringLiteral("text/plain"));
+#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_window));
+#else
         job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, m_window));
+#endif
         job->start();
         return;
     }
